// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.IO;
using System.Drawing;
using System.Text;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Drawing;

namespace DsPdfWeb.Demos
{
    // このサンプルは PDF を読み込み（Wetlands サンプルで生成された
    // ドキュメントを使用します）、そこからすべてのイメージを抽出します。
    // 次に、これらの画像を新しい PDF へ１ページにひとつずつ出力します。
    public class GetImages
    {
        public int CreatePDF(Stream stream)
        {
            var tf = new TextFormat() { Font = StandardFonts.Times, FontSize = 12 };
            using (var fs = File.OpenRead(Path.Combine("Resources", "PDFs", "Wetlands.pdf")))
            {
                var docSrc = new GcPdfDocument();
                // 既存の PDF にいくつかの画像を読み込みます。
                docSrc.Load(fs);
                // この呼び出しは、読み込まれた PDF からイメージに関する情報を抽出します。
                // 大きなファイルの場合、完了するまでに時間がかかることに注意してください。
                var imageInfos = docSrc.GetImages();

                var doc = new GcPdfDocument();
                var textPt = new PointF(72, 72);
                var imageRc = new RectangleF(72, 72 * 2, doc.PageSize.Width - 72 * 2, doc.PageSize.Height - 72 * 3);

                foreach (var imageInfo in imageInfos)
                {
                    // 同じイメージが複数の場所に表示され、imageInfo にはページの
                    // インデックスとページ上の位置が含まれます。
                    // わかりやすくするために、ここではページ番号のみを表示しています
                    var sb = new StringBuilder();
                    imageInfo.Locations.ForEach(il_ => sb.Append((il_.Page.Index + 1).ToString() + ", "));
                    var g = doc.NewPage().Graphics;
                    g.DrawString($"この画像は、元 PDF ファイルの  {sb.ToString().TrimEnd(' ', ',')} ページに表示されています。", tf, new PointF(72, 72));
                    g.DrawImage(imageInfo.Image, imageRc, null, ImageAlign.ScaleImage);
                }
                // PDF ドキュメントを保存します。
                doc.Save(stream);
                return doc.Pages.Count;
            }
        }
    }
}
